==> jetbackup5-plugin-destination-google-drive-1.1.1-2.zip: media/controller.js <==
'use strict';

define(['app'], function(app) {
	
	app.controller("destinationGoogleDrive", ["$scope", function ($scope) {

		$scope.$emit('options', { disklimit: true, threads: true });

		if($scope.details._id === undefined) $scope.saveData.threads = 45;
		if($scope.saveData.options.retries === undefined) $scope.saveData.options.retries = 5;

		$scope.openAuthentication = function() {
			
			var 
				client_id = '861329395237-h3dhd23j72smr27f2an3vukiavvd30pg.apps.googleusercontent.com',
				redirect_uri = 'https://auth.jetbackup.com/google/';
			
			var scopes = [];
			scopes.push('https://www.googleapis.com/auth/drive.file');
			scopes.push('https://www.googleapis.com/auth/userinfo.email');
			
			var url = [];
			url.push('response_type=code');
			url.push('access_type=offline');
			url.push('client_id=' + client_id);
			url.push('redirect_uri=' + redirect_uri);
			url.push('state=state_parameter_passthrough_value');
			url.push('scope=' + scopes.join(' ')); // you can add more scopes by separating by space
			url.push('approval_prompt=force');

			var features = [];
			features.push('height=600');
			features.push('width=450');
			features.push('left=' + (screen.width / 2 - 225));
			features.push('top=' + (screen.height / 2 - 200));
			features.push('toolbar=no');
			features.push('titlebar=no');
			features.push('status=no');
			features.push('scrollbars=no');
			features.push('resizable=yes');
			features.push('menubar=no');
			
			window.open('https://accounts.google.com/o/oauth2/auth?' + url.join('&'), '', features.join(','));

			return false;

		};
	}]);

});

==> jetbackup5-plugin-destination-google-drive-1.1.4-1.zip: media/controller.js <==
'use strict';

define(['app'], function(app) {
	
	app.controller("destinationGoogleDrive", ["$scope", function ($scope) {

		$scope.$emit('options', { disklimit: true, threads: true });

		if($scope.details._id === undefined) $scope.saveData.threads = 45;
		if($scope.saveData.options.retries === undefined) $scope.saveData.options.retries = 5;
		if($scope.saveData.options.client_id === undefined) $scope.saveData.options.client_id = '';
		if($scope.saveData.options.client_secret === undefined) $scope.saveData.options.client_secret = '';

		$scope.type = $scope.saveData.options.client_id || $scope.saveData.options.client_secret ? 1 : 2;
		$scope.resetOAuth = function() {
			if($scope.type == 1) return;
			$scope.saveData.options.client_id = '';
			$scope.saveData.options.client_secret = '';
		};
		
		$scope.openAuthentication = function() {
			
			var 
				client_id = $scope.type == 1 ? $scope.saveData.options.client_id : '861329395237-h3dhd23j72smr27f2an3vukiavvd30pg.apps.googleusercontent.com',
				redirect_uri = 'https://auth.jetbackup.com/google/';
			
			var scopes = [];
			scopes.push('https://www.googleapis.com/auth/drive.file');
			scopes.push('https://www.googleapis.com/auth/userinfo.email');
			
			var url = [];
			url.push('response_type=code');
			url.push('access_type=offline');
			url.push('client_id=' + client_id);
			url.push('redirect_uri=' + redirect_uri);
			url.push('state=state_parameter_passthrough_value');
			url.push('scope=' + scopes.join(' ')); // you can add more scopes by separating by space
			url.push('approval_prompt=force');

			var features = [];
			features.push('height=600');
			features.push('width=450');
			features.push('left=' + (screen.width / 2 - 225));
			features.push('top=' + (screen.height / 2 - 200));
			features.push('toolbar=no');
			features.push('titlebar=no');
			features.push('status=no');
			features.push('scrollbars=no');
			features.push('resizable=yes');
			features.push('menubar=no');
			
			window.open('https://accounts.google.com/o/oauth2/auth?' + url.join('&'), '', features.join(','));

			return false;

		};
	}]);

});
